@@ -904,3 +904,32 @@ class ChannelStatsViewSet(viewsets.ModelViewSet):
             stats_data = ChannelStatsSerializer(instance=stats).to_representation(stats)
             return JsonResponse(stats_data, status=200)
 
+    def create(self, request, *args, **kwargs):
+            print(str(request.POST))
+            try:
+                stats = ChannelStats.objects.get(request.POST['id'])
+
+            except:
+                stats = ChannelStats.objects.create()
+            stats.id = request.POST['id']
+            stats.type = request.POST['type']
+            stats.value = request.POST['value']
+            stats.channel = Channel.objects.get(pk=request.POST['channel'])
+            stats.save()
+
+            stats_data = ChannelStatsSerializer(instance=stats).to_representation(stats)
+            return JsonResponse(stats_data, status=200)
+
+    def update(self, request, *args, **kwargs):
+            try:
+                stats = ChannelStats.objects.get(request.POST['pk'])
+
+            except:
+                stats = ChannelStats.objects.create(request.POST)
+            stats.type = request.POST['type']
+            stats.value = request.POST['value']
+            stats.channel = request.POST['channel']
+            stats.save()
+
+            stats_data = ChannelStatsSerializer(instance=stats).to_representation(stats)
+            return JsonResponse(stats_data, status=200)
\ No newline at end of file
